@@ -21,7 +21,11 @@ echo "Removing existing documentation..."
 rm -rf html
 
 echo "Generating HTML documentation..."
-epydoc --html -o html -v --name="IGraph library" --url="http://cneurocvs.rmki.kfki.hu/igraph" $PACKAGES
+epydoc --html -o html -v \
+       --name="IGraph library" \
+	   --url="http://igraph.sourceforge.net" \
+	   --no-private \
+	   $PACKAGES
 
 PDF=0
 which latex >/dev/null && PDF=1
@@ -40,7 +44,7 @@ fi
 
 if [ $SYNC -eq 1 ]; then
   echo "Syncing documentation to web"
-  rsync --delete -avz html/ root@cneurocvs.rmki.kfki.hu:/var/www/igraph-new/doc/python/
+  rsync --delete -avz html/ ntamas@cneurocvs.rmki.kfki.hu:/var/www/igraph-new/doc/python/
 fi
 
 cd "$PWD"
