@@ -184,6 +184,26 @@ int igraphmodule_PyObject_to_degseq_t(PyObject *o,
   return igraphmodule_PyObject_to_enum(o, degseq_tt, (int*)result);
 }
 
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to an igraph \c igraph_tree_mode_t
+ */
+int igraphmodule_PyObject_to_tree_mode_t(PyObject *o,
+  igraph_tree_mode_t *result) {
+  static igraphmodule_enum_translation_table_entry_t tree_mode_tt[] = {
+        {"in", IGRAPH_TREE_IN},
+        {"out", IGRAPH_TREE_OUT},
+        {"all", IGRAPH_TREE_UNDIRECTED},
+        {"undirected", IGRAPH_TREE_UNDIRECTED},
+        {"tree_in", IGRAPH_TREE_IN},
+        {"tree_out", IGRAPH_TREE_OUT},
+        {"tree_all", IGRAPH_TREE_UNDIRECTED},
+        {0,0}
+    };
+
+  return igraphmodule_PyObject_to_enum(o, tree_mode_tt, (int*)result);
+}
+
 /**
  * \brief Converts a Python object to an igraph \c igraph_integer_t
  *
@@ -252,6 +272,38 @@ int igraphmodule_PyObject_to_real_t(PyObject *object, igraph_real_t *v) {
   return 1;
 }
 
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to a Python file object.
+ *
+ * If the Python object is a string, it will be interpreted as a filename
+ * and will be opened in the given mode. If the Python object is a file
+ * handle, it will be used intact.
+ *
+ * \param object a Python object to be converted
+ * \param mode   file opening mode if the Python object is a string.
+ * \return the file object if everything is OK, NULL otherwise.
+ *   An appropriate exception is raised in this case.
+ */
+PyObject* igraphmodule_PyObject_to_PyFile(PyObject *object, char* mode) {
+    PyObject* result;
+
+    if (object == NULL) {
+    } else if (PyString_Check(object)) {
+        result = PyFile_FromString(PyString_AsString(object), mode);
+        return result;
+    } else if (PyFile_Check(object)) {
+        /* Check if the file object has a corresponding FILE* handle */
+        if (PyFile_AsFile(object) == NULL)
+            return NULL;
+
+        Py_INCREF(object);
+        return object;
+    }
+    PyErr_SetString(PyExc_TypeError, "string or file handle expected");
+    return NULL;
+}
+
 /**
  * \ingroup python_interface_conversion
  * \brief Converts a Python object to an igraph \c igraph_vector_t
@@ -681,7 +733,10 @@ PyObject* igraphmodule_vector_t_to_PyList(igraph_vector_t *v,
   list=PyList_New(n);
   for (i=0; i<n; i++) {
     if (type == IGRAPHMODULE_TYPE_INT) {
-      item=PyInt_FromLong((long)VECTOR(*v)[i]);
+	  if (!igraph_finite(VECTOR(*v)[i]))
+		item=PyFloat_FromDouble((double)VECTOR(*v)[i]);
+	  else
+        item=PyInt_FromLong((long)VECTOR(*v)[i]);
     } else if (type == IGRAPHMODULE_TYPE_FLOAT) {
       item=PyFloat_FromDouble((double)VECTOR(*v)[i]);
     } else {
@@ -1012,10 +1067,13 @@ PyObject* igraphmodule_matrix_t_to_PyList(igraph_matrix_t *m,
     row=PyList_New(nc);
     for (j=0; j<nc; j++) 
       {
-         if (type==IGRAPHMODULE_TYPE_INT)
-           item=PyInt_FromLong(MATRIX(*m,i,j));
-         else
-           item=PyFloat_FromDouble(MATRIX(*m,i,j));
+         if (type==IGRAPHMODULE_TYPE_INT) {
+	       if (!igraph_finite(MATRIX(*m, i, j)))
+		     item=PyFloat_FromDouble((double)MATRIX(*m, i, j));
+	       else
+             item=PyInt_FromLong((long)MATRIX(*m, i, j));
+		 } else
+           item=PyFloat_FromDouble(MATRIX(*m, i, j));
            
          if (PyList_SetItem(row, j, item))
            {
