@@ -43,15 +43,17 @@ typedef struct {
 
 int igraphmodule_PyObject_to_enum(PyObject *o,
   igraphmodule_enum_translation_table_entry_t *table, int *result);
-int igraphmodule_PyObject_to_bliss_sh_t(PyObject *o, igraph_bliss_sh_t *result);
-int igraphmodule_PyObject_to_vconn_nei_t(PyObject *o, igraph_vconn_nei_t *result);
-int igraphmodule_PyObject_to_neimode_t(PyObject *o, igraph_neimode_t *result);
 int igraphmodule_PyObject_to_adjacency_t(PyObject *o, igraph_adjacency_t *result);
+int igraphmodule_PyObject_to_bliss_sh_t(PyObject *o, igraph_bliss_sh_t *result);
 int igraphmodule_PyObject_to_connectedness_t(PyObject *o, igraph_connectedness_t *result);
 int igraphmodule_PyObject_to_degseq_t(PyObject *o, igraph_degseq_t *result);
+int igraphmodule_PyObject_to_neimode_t(PyObject *o, igraph_neimode_t *result);
+int igraphmodule_PyObject_to_tree_mode_t(PyObject *o, igraph_tree_mode_t *result);
+int igraphmodule_PyObject_to_vconn_nei_t(PyObject *o, igraph_vconn_nei_t *result);
 
 int igraphmodule_PyObject_to_integer_t(PyObject *object, igraph_real_t *v);
 int igraphmodule_PyObject_to_real_t(PyObject *object, igraph_real_t *v);
+PyObject* igraphmodule_PyObject_to_PyFile(PyObject *object, char* mode);
 
 int igraphmodule_PyObject_to_vector_t(PyObject *list, igraph_vector_t *v, igraph_bool_t need_non_negative, igraph_bool_t pairs);
 int igraphmodule_PyObject_float_to_vector_t(PyObject *list, igraph_vector_t *v);
