@@ -970,7 +970,7 @@ int igraphmodule_i_get_numeric_vertex_attr(const igraph_t *graph,
   if (igraph_vs_is_all(&vs)) {
     if (igraphmodule_PyObject_float_to_vector_t(list, &newvalue))
       IGRAPH_ERROR("Internal error", IGRAPH_EINVAL);
-    igraph_vector_copy(value, &newvalue);
+    igraph_vector_update(value, &newvalue);
     igraph_vector_destroy(&newvalue);
   } else {
     igraph_vit_t it;
@@ -1049,7 +1049,7 @@ int igraphmodule_i_get_numeric_edge_attr(const igraph_t *graph,
   if (igraph_es_is_all(&es)) {
     if (igraphmodule_PyObject_float_to_vector_t(list, &newvalue))
       IGRAPH_ERROR("Internal error", IGRAPH_EINVAL);
-    igraph_vector_copy(value, &newvalue);
+    igraph_vector_update(value, &newvalue);
     igraph_vector_destroy(&newvalue);
   } else {
     igraph_eit_t it;
@@ -1246,7 +1246,7 @@ PyMODINIT_FUNC initcore(void) {
   PyModule_AddIntConstant(m, "BLISS_FSM", IGRAPH_BLISS_FSM);
 
   /* More useful constants */
-  PyModule_AddStringConstant(m, "__version__", "0.5.2");
+  PyModule_AddStringConstant(m, "__version__", "0.5.3");
   PyModule_AddStringConstant(m, "__build_date__", __DATE__);
 
   /* initialize error, progress, warning and interruption handler */
