@@ -307,14 +307,27 @@ PyObject* igraphmodule_VertexSeq_get_attribute_values_mapping(igraphmodule_Verte
   if (PyInt_Check(o)) return igraphmodule_VertexSeq_sq_item(self, PyInt_AsLong(o));
   if (PyTuple_Check(o)) {
     /* Return a restricted VertexSeq */
+    if (PyTuple_Size(o) == 0) {
+      PyObject *args, *result;
+      args = Py_BuildValue("(O)", Py_None);
+      result = igraphmodule_VertexSeq_select(self, args, NULL);
+      Py_DECREF(args);
+      return result;
+    }
     return igraphmodule_VertexSeq_select(self, o, NULL);
-  } else if (PyList_Check(o)) {
+  } else if (PySlice_Check(o) || PyList_Check(o)) {
     /* Return a restricted VertexSeq */
-    PyObject *t = PyList_AsTuple(o);
-    PyObject *result;
-    if (!t) return NULL;
-    result = igraphmodule_VertexSeq_select(self, t, NULL);
-    Py_DECREF(t);
+    PyObject *result, *args;
+    if (PySlice_Check(o)) {
+      args = Py_BuildValue("(O)", o);
+    } else if (PyList_Size(o) == 0) {
+      args = Py_BuildValue("(O)", Py_None);
+    } else {
+      args = PyList_AsTuple(o);
+    }
+    if (!args) return NULL;
+    result = igraphmodule_VertexSeq_select(self, args, NULL);
+    Py_DECREF(args);
     return result;
   }
   return igraphmodule_VertexSeq_get_attribute_values(self, o);
@@ -344,7 +357,7 @@ int igraphmodule_VertexSeq_set_attribute_values_mapping(igraphmodule_VertexSeqOb
 
   if (igraph_vs_type(&self->vs) == IGRAPH_VS_ALL) {
     if (n != (long)igraph_vcount(&gr->g)) {
-      PyErr_SetString(PyExc_ValueError, "value list length must be equal to the number of vertices in the graph");
+      PyErr_SetString(PyExc_ValueError, "value list length must be equal to the number of vertices in the vertex sequence");
       return -1;
     }
 
@@ -377,6 +390,7 @@ int igraphmodule_VertexSeq_set_attribute_values_mapping(igraphmodule_VertexSeqOb
         Py_DECREF(list);
         return -1;
       }
+      Py_DECREF(list);    /* PyDict_SetItem increased the refcount */
     }
   } else {
     /* We are working with a subset of the graph. Convert the sequence to a
@@ -412,6 +426,7 @@ int igraphmodule_VertexSeq_set_attribute_values_mapping(igraphmodule_VertexSeqOb
           return -1;
         } /* PyList_SetItem stole a reference to the item automatically */ 
       }
+      igraph_vector_destroy(&vs);
     } else if (values != 0) {
       /* We don't have attributes with the given name yet. Create an entry
        * in the dict, create a new list, fill with None for vertices not in the
@@ -441,6 +456,7 @@ int igraphmodule_VertexSeq_set_attribute_values_mapping(igraphmodule_VertexSeqOb
         Py_DECREF(list);
         return -1;
       }
+      Py_DECREF(list);    /* PyDict_SetItem increased the refcount */
     }
   }
 
@@ -477,8 +493,10 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
 
   /* First, filter by positional arguments */
   n = PyTuple_Size(args);
+
   for (i=0; i<n; i++) {
     PyObject *item = PyTuple_GET_ITEM(args, i);
+
     if (item == Py_None) {
       /* None means: select nothing */
       igraph_vs_destroy(&result->vs);
@@ -546,7 +564,7 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
         igraphmodule_handle_igraph_error();
         return 0;
       }
-      if (igraph_vs_as_vector(&gr->g, result->vs, &v2)) {
+      if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
         igraph_vector_destroy(&v);
         igraph_vector_destroy(&v2);
         igraphmodule_handle_igraph_error();
@@ -581,35 +599,68 @@ PyObject* igraphmodule_VertexSeq_select(igraphmodule_VertexSeqObject *self,
       }
       igraph_vector_destroy(&v);
     } else {
-      /* Iterators and everything that was not handled directly */
-      PyObject *iter, *item2;
+      /* Iterators, slices and everything that was not handled directly */
+      PyObject *iter=0, *item2;
       igraph_vector_t v, v2;
-      
-      iter = PyObject_GetIter(item);
-      if (iter == 0) {
-        PyErr_SetString(PyExc_TypeError, "invalid vertex filter among positional arguments");
+
+      /* Allocate stuff */
+      if (igraph_vector_init(&v, 0)) {
+        igraphmodule_handle_igraph_error();
         Py_DECREF(result);
         return 0;
       }
-      /* Allocate stuff */
-      if (igraph_vector_init(&v, 0)) {
-        Py_DECREF(iter);
-        igraphmodule_handle_igraph_error();
-        return 0;
-      }
       if (igraph_vector_init(&v2, 0)) {
-        Py_DECREF(iter);
         igraph_vector_destroy(&v);
+        Py_DECREF(result);
         igraphmodule_handle_igraph_error();
         return 0;
       }
-      if (igraph_vs_as_vector(&gr->g, result->vs, &v2)) {
-        Py_DECREF(iter);
+      if (igraph_vs_as_vector(&gr->g, self->vs, &v2)) {
         igraph_vector_destroy(&v);
         igraph_vector_destroy(&v2);
+        Py_DECREF(result);
         igraphmodule_handle_igraph_error();
         return 0;
       }
+
+      /* Create an appropriate iterator */
+      if (PySlice_Check(item)) {
+        /* Create an iterator from the slice (which is not iterable by default )*/
+        Py_ssize_t start, stop, step, sl;
+        PyObject* range;
+        igraph_bool_t ok;
+
+        ok = (PySlice_GetIndicesEx((PySliceObject*)item, igraph_vector_size(&v2),
+              &start, &stop, &step, &sl) == 0);
+        if (ok) {
+          range = PyObject_CallFunction((PyObject*)&PyRange_Type, "lll", start, stop, step);
+          ok = (range != 0);
+        }
+        if (ok) {
+          iter = PyObject_GetIter(range);
+          Py_DECREF(range);
+          ok = (iter != 0);
+        }
+        if (!ok) {
+          igraph_vector_destroy(&v);
+          igraph_vector_destroy(&v2);
+          PyErr_SetString(PyExc_TypeError, "error while converting slice to iterator");
+          Py_DECREF(result);
+          return 0;
+        }
+      } else {
+        /* Simply create the iterator corresponding to the object */
+        iter = PyObject_GetIter(item);
+      }
+
+      /* Did we manage to get an iterator? */
+      if (iter == 0) {
+        igraph_vector_destroy(&v);
+        igraph_vector_destroy(&v2);
+        PyErr_SetString(PyExc_TypeError, "invalid vertex filter among positional arguments");
+        Py_DECREF(result);
+        return 0;
+      }
       /* Do the iteration */
       while ((item2=PyIter_Next(iter)) != 0) {
         if (PyInt_Check(item2)) {
